/*
 * sdequser.c
 *
 * MontaVista System Device Enumeration Event Queue Userland Implementation
 *
 * Author: MontaVista Software, Inc.
 *         Steven Dake (sdake@mvista.com)
 *         source@mvista.com
 *
 * Copyright 2003 MontaVista Software Inc.
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by the
 *  Free Software Foundation; either version 2 of the License, or (at your
 *  option) any later version.
 *
 *  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED
 *  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 *  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 *  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 *  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 *  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 *  TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 *  USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <stdio.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/ioctl.h>
#include <fcntl.h>
#include <linux/sdeq.h>
#include <string.h>
#include "sdequser.h"

static int sdeq_fd;

int sdeq_init (int *fd) {
	sdeq_fd = open ("/dev/sdeq", O_RDWR);

	*fd = sdeq_fd;
	return (0);
}

int sdeq_get_currevent (struct sdeq_event *event)
{
	int result;
	struct ioctl_get_currevent ioctl_get_currevent;

	result = ioctl (sdeq_fd, IOCTL_SDEQ_GET_CURREVENT, &ioctl_get_currevent);
	memcpy (event, &ioctl_get_currevent.event, sizeof (struct sdeq_event));

	return (result);
}

int sdeq_reset_currptr (void)
{
	int result;

	result = ioctl (sdeq_fd, IOCTL_SDEQ_RESET_CURRPTR, NULL);

	return (result);
}

int sdeq_remove_events (int event_count)
{
	int result;
	struct ioctl_remove_events ioctl_remove_events;

	ioctl_remove_events.event_count = event_count;

	result = ioctl (sdeq_fd, IOCTL_SDEQ_REMOVE_EVENTS, &ioctl_remove_events);

	return (result);
}
